# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/staking/v1beta1/genesis.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/staking/v1beta1/genesis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.staking.v1beta1 import staking_pb2 as cosmos_dot_staking_dot_v1beta1_dot_staking__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/staking/v1beta1/genesis.proto\x12\x16\x63osmos.staking.v1beta1\x1a\x14gogoproto/gogo.proto\x1a$cosmos/staking/v1beta1/staking.proto\"\xdd\x04\n\x0cGenesisState\x12\x34\n\x06params\x18\x01 \x01(\x0b\x32\x1e.cosmos.staking.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12\x63\n\x10last_total_power\x18\x02 \x01(\x0c\x42I\xc8\xde\x1f\x00\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x17yaml:\"last_total_power\"\x12o\n\x15last_validator_powers\x18\x03 \x03(\x0b\x32*.cosmos.staking.v1beta1.LastValidatorPowerB$\xc8\xde\x1f\x00\xf2\xde\x1f\x1cyaml:\"last_validator_powers\"\x12;\n\nvalidators\x18\x04 \x03(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\x04\xc8\xde\x1f\x00\x12=\n\x0b\x64\x65legations\x18\x05 \x03(\x0b\x32\".cosmos.staking.v1beta1.DelegationB\x04\xc8\xde\x1f\x00\x12p\n\x15unbonding_delegations\x18\x06 \x03(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB$\xc8\xde\x1f\x00\xf2\xde\x1f\x1cyaml:\"unbonding_delegations\"\x12\x41\n\rredelegations\x18\x07 \x03(\x0b\x32$.cosmos.staking.v1beta1.RedelegationB\x04\xc8\xde\x1f\x00\x12\x10\n\x08\x65xported\x18\x08 \x01(\x08\">\n\x12LastValidatorPower\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05power\x18\x02 \x01(\x03:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x42.Z,github.com/cosmos/cosmos-sdk/x/staking/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.staking.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/staking/types'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['last_total_power']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['last_total_power']._serialized_options = b'\310\336\037\000\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\027yaml:\"last_total_power\"'
  _globals['_GENESISSTATE'].fields_by_name['last_validator_powers']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['last_validator_powers']._serialized_options = b'\310\336\037\000\362\336\037\034yaml:\"last_validator_powers\"'
  _globals['_GENESISSTATE'].fields_by_name['validators']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['validators']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['delegations']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['delegations']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['unbonding_delegations']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['unbonding_delegations']._serialized_options = b'\310\336\037\000\362\336\037\034yaml:\"unbonding_delegations\"'
  _globals['_GENESISSTATE'].fields_by_name['redelegations']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['redelegations']._serialized_options = b'\310\336\037\000'
  _globals['_LASTVALIDATORPOWER']._loaded_options = None
  _globals['_LASTVALIDATORPOWER']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_GENESISSTATE']._serialized_start=125
  _globals['_GENESISSTATE']._serialized_end=730
  _globals['_LASTVALIDATORPOWER']._serialized_start=732
  _globals['_LASTVALIDATORPOWER']._serialized_end=794
# @@protoc_insertion_point(module_scope)



from amino import amino_pb2 as _amino_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmwasm.wasm.v1 import types_pb2 as _types_pb2
from google.api import annotations_pb2 as _annotations_pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryContractInfoRequest(_message.Message):
    __slots__ = ("address",)
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class QueryContractInfoResponse(_message.Message):
    __slots__ = ("address", "contract_info")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_INFO_FIELD_NUMBER: _ClassVar[int]
    address: str
    contract_info: _types_pb2.ContractInfo
    def __init__(self, address: _Optional[str] = ..., contract_info: _Optional[_Union[_types_pb2.ContractInfo, _Mapping]] = ...) -> None: ...

class QueryContractHistoryRequest(_message.Message):
    __slots__ = ("address", "pagination")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, address: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryContractHistoryResponse(_message.Message):
    __slots__ = ("entries", "pagination")
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    entries: _containers.RepeatedCompositeFieldContainer[_types_pb2.ContractCodeHistoryEntry]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, entries: _Optional[_Iterable[_Union[_types_pb2.ContractCodeHistoryEntry, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryContractsByCodeRequest(_message.Message):
    __slots__ = ("code_id", "pagination")
    CODE_ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    code_id: int
    pagination: _pagination_pb2.PageRequest
    def __init__(self, code_id: _Optional[int] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryContractsByCodeResponse(_message.Message):
    __slots__ = ("contracts", "pagination")
    CONTRACTS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    contracts: _containers.RepeatedScalarFieldContainer[str]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, contracts: _Optional[_Iterable[str]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryAllContractStateRequest(_message.Message):
    __slots__ = ("address", "pagination")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, address: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryAllContractStateResponse(_message.Message):
    __slots__ = ("models", "pagination")
    MODELS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    models: _containers.RepeatedCompositeFieldContainer[_types_pb2.Model]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, models: _Optional[_Iterable[_Union[_types_pb2.Model, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryRawContractStateRequest(_message.Message):
    __slots__ = ("address", "query_data")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    QUERY_DATA_FIELD_NUMBER: _ClassVar[int]
    address: str
    query_data: bytes
    def __init__(self, address: _Optional[str] = ..., query_data: _Optional[bytes] = ...) -> None: ...

class QueryRawContractStateResponse(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    def __init__(self, data: _Optional[bytes] = ...) -> None: ...

class QuerySmartContractStateRequest(_message.Message):
    __slots__ = ("address", "query_data")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    QUERY_DATA_FIELD_NUMBER: _ClassVar[int]
    address: str
    query_data: bytes
    def __init__(self, address: _Optional[str] = ..., query_data: _Optional[bytes] = ...) -> None: ...

class QuerySmartContractStateResponse(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    def __init__(self, data: _Optional[bytes] = ...) -> None: ...

class QueryCodeRequest(_message.Message):
    __slots__ = ("code_id",)
    CODE_ID_FIELD_NUMBER: _ClassVar[int]
    code_id: int
    def __init__(self, code_id: _Optional[int] = ...) -> None: ...

class CodeInfoResponse(_message.Message):
    __slots__ = ("code_id", "creator", "data_hash", "instantiate_permission")
    CODE_ID_FIELD_NUMBER: _ClassVar[int]
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    DATA_HASH_FIELD_NUMBER: _ClassVar[int]
    INSTANTIATE_PERMISSION_FIELD_NUMBER: _ClassVar[int]
    code_id: int
    creator: str
    data_hash: bytes
    instantiate_permission: _types_pb2.AccessConfig
    def __init__(self, code_id: _Optional[int] = ..., creator: _Optional[str] = ..., data_hash: _Optional[bytes] = ..., instantiate_permission: _Optional[_Union[_types_pb2.AccessConfig, _Mapping]] = ...) -> None: ...

class QueryCodeResponse(_message.Message):
    __slots__ = ("code_info", "data")
    CODE_INFO_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    code_info: CodeInfoResponse
    data: bytes
    def __init__(self, code_info: _Optional[_Union[CodeInfoResponse, _Mapping]] = ..., data: _Optional[bytes] = ...) -> None: ...

class QueryCodesRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryCodesResponse(_message.Message):
    __slots__ = ("code_infos", "pagination")
    CODE_INFOS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    code_infos: _containers.RepeatedCompositeFieldContainer[CodeInfoResponse]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, code_infos: _Optional[_Iterable[_Union[CodeInfoResponse, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryPinnedCodesRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryPinnedCodesResponse(_message.Message):
    __slots__ = ("code_ids", "pagination")
    CODE_IDS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    code_ids: _containers.RepeatedScalarFieldContainer[int]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, code_ids: _Optional[_Iterable[int]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from cometbft.services.pruning.v1 import pruning_pb2 as cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in cometbft/services/pruning/v1/service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class PruningServiceStub(object):
    """PruningService provides privileged access to specialized pruning
    functionality on the CometBFT node to help control node storage.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetBlockRetainHeight = channel.unary_unary(
                '/cometbft.services.pruning.v1.PruningService/SetBlockRetainHeight',
                request_serializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetBlockRetainHeightRequest.SerializeToString,
                response_deserializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetBlockRetainHeightResponse.FromString,
                _registered_method=True)
        self.GetBlockRetainHeight = channel.unary_unary(
                '/cometbft.services.pruning.v1.PruningService/GetBlockRetainHeight',
                request_serializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetBlockRetainHeightRequest.SerializeToString,
                response_deserializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetBlockRetainHeightResponse.FromString,
                _registered_method=True)
        self.SetBlockResultsRetainHeight = channel.unary_unary(
                '/cometbft.services.pruning.v1.PruningService/SetBlockResultsRetainHeight',
                request_serializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetBlockResultsRetainHeightRequest.SerializeToString,
                response_deserializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetBlockResultsRetainHeightResponse.FromString,
                _registered_method=True)
        self.GetBlockResultsRetainHeight = channel.unary_unary(
                '/cometbft.services.pruning.v1.PruningService/GetBlockResultsRetainHeight',
                request_serializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetBlockResultsRetainHeightRequest.SerializeToString,
                response_deserializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetBlockResultsRetainHeightResponse.FromString,
                _registered_method=True)
        self.SetTxIndexerRetainHeight = channel.unary_unary(
                '/cometbft.services.pruning.v1.PruningService/SetTxIndexerRetainHeight',
                request_serializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetTxIndexerRetainHeightRequest.SerializeToString,
                response_deserializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetTxIndexerRetainHeightResponse.FromString,
                _registered_method=True)
        self.GetTxIndexerRetainHeight = channel.unary_unary(
                '/cometbft.services.pruning.v1.PruningService/GetTxIndexerRetainHeight',
                request_serializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetTxIndexerRetainHeightRequest.SerializeToString,
                response_deserializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetTxIndexerRetainHeightResponse.FromString,
                _registered_method=True)
        self.SetBlockIndexerRetainHeight = channel.unary_unary(
                '/cometbft.services.pruning.v1.PruningService/SetBlockIndexerRetainHeight',
                request_serializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetBlockIndexerRetainHeightRequest.SerializeToString,
                response_deserializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetBlockIndexerRetainHeightResponse.FromString,
                _registered_method=True)
        self.GetBlockIndexerRetainHeight = channel.unary_unary(
                '/cometbft.services.pruning.v1.PruningService/GetBlockIndexerRetainHeight',
                request_serializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetBlockIndexerRetainHeightRequest.SerializeToString,
                response_deserializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetBlockIndexerRetainHeightResponse.FromString,
                _registered_method=True)


class PruningServiceServicer(object):
    """PruningService provides privileged access to specialized pruning
    functionality on the CometBFT node to help control node storage.
    """

    def SetBlockRetainHeight(self, request, context):
        """SetBlockRetainHeightRequest indicates to the node that it can safely
        prune all block data up to the specified retain height.

        The lower of this retain height and that set by the application in its
        Commit response will be used by the node to determine which heights' data
        can be pruned.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockRetainHeight(self, request, context):
        """GetBlockRetainHeight returns information about the retain height
        parameters used by the node to influence block retention/pruning.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetBlockResultsRetainHeight(self, request, context):
        """SetBlockResultsRetainHeightRequest indicates to the node that it can
        safely prune all block results data up to the specified height.

        The node will always store the block results for the latest height to
        help facilitate crash recovery.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockResultsRetainHeight(self, request, context):
        """GetBlockResultsRetainHeight returns information about the retain height
        parameters used by the node to influence block results retention/pruning.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetTxIndexerRetainHeight(self, request, context):
        """SetTxIndexerRetainHeightRequest indicates to the node that it can safely
        prune all tx indices up to the specified retain height.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTxIndexerRetainHeight(self, request, context):
        """GetTxIndexerRetainHeight returns information about the retain height
        parameters used by the node to influence TxIndexer pruning
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetBlockIndexerRetainHeight(self, request, context):
        """SetBlockIndexerRetainHeightRequest indicates to the node that it can safely
        prune all block indices up to the specified retain height.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockIndexerRetainHeight(self, request, context):
        """GetBlockIndexerRetainHeight returns information about the retain height
        parameters used by the node to influence BlockIndexer pruning
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PruningServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetBlockRetainHeight': grpc.unary_unary_rpc_method_handler(
                    servicer.SetBlockRetainHeight,
                    request_deserializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetBlockRetainHeightRequest.FromString,
                    response_serializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetBlockRetainHeightResponse.SerializeToString,
            ),
            'GetBlockRetainHeight': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockRetainHeight,
                    request_deserializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetBlockRetainHeightRequest.FromString,
                    response_serializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetBlockRetainHeightResponse.SerializeToString,
            ),
            'SetBlockResultsRetainHeight': grpc.unary_unary_rpc_method_handler(
                    servicer.SetBlockResultsRetainHeight,
                    request_deserializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetBlockResultsRetainHeightRequest.FromString,
                    response_serializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetBlockResultsRetainHeightResponse.SerializeToString,
            ),
            'GetBlockResultsRetainHeight': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockResultsRetainHeight,
                    request_deserializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetBlockResultsRetainHeightRequest.FromString,
                    response_serializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetBlockResultsRetainHeightResponse.SerializeToString,
            ),
            'SetTxIndexerRetainHeight': grpc.unary_unary_rpc_method_handler(
                    servicer.SetTxIndexerRetainHeight,
                    request_deserializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetTxIndexerRetainHeightRequest.FromString,
                    response_serializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetTxIndexerRetainHeightResponse.SerializeToString,
            ),
            'GetTxIndexerRetainHeight': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTxIndexerRetainHeight,
                    request_deserializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetTxIndexerRetainHeightRequest.FromString,
                    response_serializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetTxIndexerRetainHeightResponse.SerializeToString,
            ),
            'SetBlockIndexerRetainHeight': grpc.unary_unary_rpc_method_handler(
                    servicer.SetBlockIndexerRetainHeight,
                    request_deserializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetBlockIndexerRetainHeightRequest.FromString,
                    response_serializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetBlockIndexerRetainHeightResponse.SerializeToString,
            ),
            'GetBlockIndexerRetainHeight': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockIndexerRetainHeight,
                    request_deserializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetBlockIndexerRetainHeightRequest.FromString,
                    response_serializer=cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetBlockIndexerRetainHeightResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cometbft.services.pruning.v1.PruningService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cometbft.services.pruning.v1.PruningService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class PruningService(object):
    """PruningService provides privileged access to specialized pruning
    functionality on the CometBFT node to help control node storage.
    """

    @staticmethod
    def SetBlockRetainHeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cometbft.services.pruning.v1.PruningService/SetBlockRetainHeight',
            cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetBlockRetainHeightRequest.SerializeToString,
            cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetBlockRetainHeightResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlockRetainHeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cometbft.services.pruning.v1.PruningService/GetBlockRetainHeight',
            cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetBlockRetainHeightRequest.SerializeToString,
            cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetBlockRetainHeightResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetBlockResultsRetainHeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cometbft.services.pruning.v1.PruningService/SetBlockResultsRetainHeight',
            cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetBlockResultsRetainHeightRequest.SerializeToString,
            cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetBlockResultsRetainHeightResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlockResultsRetainHeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cometbft.services.pruning.v1.PruningService/GetBlockResultsRetainHeight',
            cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetBlockResultsRetainHeightRequest.SerializeToString,
            cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetBlockResultsRetainHeightResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetTxIndexerRetainHeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cometbft.services.pruning.v1.PruningService/SetTxIndexerRetainHeight',
            cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetTxIndexerRetainHeightRequest.SerializeToString,
            cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetTxIndexerRetainHeightResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTxIndexerRetainHeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cometbft.services.pruning.v1.PruningService/GetTxIndexerRetainHeight',
            cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetTxIndexerRetainHeightRequest.SerializeToString,
            cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetTxIndexerRetainHeightResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetBlockIndexerRetainHeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cometbft.services.pruning.v1.PruningService/SetBlockIndexerRetainHeight',
            cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetBlockIndexerRetainHeightRequest.SerializeToString,
            cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.SetBlockIndexerRetainHeightResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetBlockIndexerRetainHeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cometbft.services.pruning.v1.PruningService/GetBlockIndexerRetainHeight',
            cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetBlockIndexerRetainHeightRequest.SerializeToString,
            cometbft_dot_services_dot_pruning_dot_v1_dot_pruning__pb2.GetBlockIndexerRetainHeightResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gogoproto/gogo.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gogoproto/gogo.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14gogoproto/gogo.proto\x12\tgogoproto\x1a google/protobuf/descriptor.proto:;\n\x13goproto_enum_prefix\x12\x1c.google.protobuf.EnumOptions\x18\xb1\xe4\x03 \x01(\x08:=\n\x15goproto_enum_stringer\x12\x1c.google.protobuf.EnumOptions\x18\xc5\xe4\x03 \x01(\x08:5\n\renum_stringer\x12\x1c.google.protobuf.EnumOptions\x18\xc6\xe4\x03 \x01(\x08:7\n\x0f\x65num_customname\x12\x1c.google.protobuf.EnumOptions\x18\xc7\xe4\x03 \x01(\t:0\n\x08\x65numdecl\x12\x1c.google.protobuf.EnumOptions\x18\xc8\xe4\x03 \x01(\x08:A\n\x14\x65numvalue_customname\x12!.google.protobuf.EnumValueOptions\x18\xd1\x83\x04 \x01(\t:;\n\x13goproto_getters_all\x12\x1c.google.protobuf.FileOptions\x18\x99\xec\x03 \x01(\x08:?\n\x17goproto_enum_prefix_all\x12\x1c.google.protobuf.FileOptions\x18\x9a\xec\x03 \x01(\x08:<\n\x14goproto_stringer_all\x12\x1c.google.protobuf.FileOptions\x18\x9b\xec\x03 \x01(\x08:9\n\x11verbose_equal_all\x12\x1c.google.protobuf.FileOptions\x18\x9c\xec\x03 \x01(\x08:0\n\x08\x66\x61\x63\x65_all\x12\x1c.google.protobuf.FileOptions\x18\x9d\xec\x03 \x01(\x08:4\n\x0cgostring_all\x12\x1c.google.protobuf.FileOptions\x18\x9e\xec\x03 \x01(\x08:4\n\x0cpopulate_all\x12\x1c.google.protobuf.FileOptions\x18\x9f\xec\x03 \x01(\x08:4\n\x0cstringer_all\x12\x1c.google.protobuf.FileOptions\x18\xa0\xec\x03 \x01(\x08:3\n\x0bonlyone_all\x12\x1c.google.protobuf.FileOptions\x18\xa1\xec\x03 \x01(\x08:1\n\tequal_all\x12\x1c.google.protobuf.FileOptions\x18\xa5\xec\x03 \x01(\x08:7\n\x0f\x64\x65scription_all\x12\x1c.google.protobuf.FileOptions\x18\xa6\xec\x03 \x01(\x08:3\n\x0btestgen_all\x12\x1c.google.protobuf.FileOptions\x18\xa7\xec\x03 \x01(\x08:4\n\x0c\x62\x65nchgen_all\x12\x1c.google.protobuf.FileOptions\x18\xa8\xec\x03 \x01(\x08:5\n\rmarshaler_all\x12\x1c.google.protobuf.FileOptions\x18\xa9\xec\x03 \x01(\x08:7\n\x0funmarshaler_all\x12\x1c.google.protobuf.FileOptions\x18\xaa\xec\x03 \x01(\x08:<\n\x14stable_marshaler_all\x12\x1c.google.protobuf.FileOptions\x18\xab\xec\x03 \x01(\x08:1\n\tsizer_all\x12\x1c.google.protobuf.FileOptions\x18\xac\xec\x03 \x01(\x08:A\n\x19goproto_enum_stringer_all\x12\x1c.google.protobuf.FileOptions\x18\xad\xec\x03 \x01(\x08:9\n\x11\x65num_stringer_all\x12\x1c.google.protobuf.FileOptions\x18\xae\xec\x03 \x01(\x08:<\n\x14unsafe_marshaler_all\x12\x1c.google.protobuf.FileOptions\x18\xaf\xec\x03 \x01(\x08:>\n\x16unsafe_unmarshaler_all\x12\x1c.google.protobuf.FileOptions\x18\xb0\xec\x03 \x01(\x08:B\n\x1agoproto_extensions_map_all\x12\x1c.google.protobuf.FileOptions\x18\xb1\xec\x03 \x01(\x08:@\n\x18goproto_unrecognized_all\x12\x1c.google.protobuf.FileOptions\x18\xb2\xec\x03 \x01(\x08:8\n\x10gogoproto_import\x12\x1c.google.protobuf.FileOptions\x18\xb3\xec\x03 \x01(\x08:6\n\x0eprotosizer_all\x12\x1c.google.protobuf.FileOptions\x18\xb4\xec\x03 \x01(\x08:3\n\x0b\x63ompare_all\x12\x1c.google.protobuf.FileOptions\x18\xb5\xec\x03 \x01(\x08:4\n\x0ctypedecl_all\x12\x1c.google.protobuf.FileOptions\x18\xb6\xec\x03 \x01(\x08:4\n\x0c\x65numdecl_all\x12\x1c.google.protobuf.FileOptions\x18\xb7\xec\x03 \x01(\x08:<\n\x14goproto_registration\x12\x1c.google.protobuf.FileOptions\x18\xb8\xec\x03 \x01(\x08:7\n\x0fmessagename_all\x12\x1c.google.protobuf.FileOptions\x18\xb9\xec\x03 \x01(\x08:=\n\x15goproto_sizecache_all\x12\x1c.google.protobuf.FileOptions\x18\xba\xec\x03 \x01(\x08:;\n\x13goproto_unkeyed_all\x12\x1c.google.protobuf.FileOptions\x18\xbb\xec\x03 \x01(\x08::\n\x0fgoproto_getters\x12\x1f.google.protobuf.MessageOptions\x18\x81\xf4\x03 \x01(\x08:;\n\x10goproto_stringer\x12\x1f.google.protobuf.MessageOptions\x18\x83\xf4\x03 \x01(\x08:8\n\rverbose_equal\x12\x1f.google.protobuf.MessageOptions\x18\x84\xf4\x03 \x01(\x08:/\n\x04\x66\x61\x63\x65\x12\x1f.google.protobuf.MessageOptions\x18\x85\xf4\x03 \x01(\x08:3\n\x08gostring\x12\x1f.google.protobuf.MessageOptions\x18\x86\xf4\x03 \x01(\x08:3\n\x08populate\x12\x1f.google.protobuf.MessageOptions\x18\x87\xf4\x03 \x01(\x08:3\n\x08stringer\x12\x1f.google.protobuf.MessageOptions\x18\xc0\x8b\x04 \x01(\x08:2\n\x07onlyone\x12\x1f.google.protobuf.MessageOptions\x18\x89\xf4\x03 \x01(\x08:0\n\x05\x65qual\x12\x1f.google.protobuf.MessageOptions\x18\x8d\xf4\x03 \x01(\x08:6\n\x0b\x64\x65scription\x12\x1f.google.protobuf.MessageOptions\x18\x8e\xf4\x03 \x01(\x08:2\n\x07testgen\x12\x1f.google.protobuf.MessageOptions\x18\x8f\xf4\x03 \x01(\x08:3\n\x08\x62\x65nchgen\x12\x1f.google.protobuf.MessageOptions\x18\x90\xf4\x03 \x01(\x08:4\n\tmarshaler\x12\x1f.google.protobuf.MessageOptions\x18\x91\xf4\x03 \x01(\x08:6\n\x0bunmarshaler\x12\x1f.google.protobuf.MessageOptions\x18\x92\xf4\x03 \x01(\x08:;\n\x10stable_marshaler\x12\x1f.google.protobuf.MessageOptions\x18\x93\xf4\x03 \x01(\x08:0\n\x05sizer\x12\x1f.google.protobuf.MessageOptions\x18\x94\xf4\x03 \x01(\x08:;\n\x10unsafe_marshaler\x12\x1f.google.protobuf.MessageOptions\x18\x97\xf4\x03 \x01(\x08:=\n\x12unsafe_unmarshaler\x12\x1f.google.protobuf.MessageOptions\x18\x98\xf4\x03 \x01(\x08:A\n\x16goproto_extensions_map\x12\x1f.google.protobuf.MessageOptions\x18\x99\xf4\x03 \x01(\x08:?\n\x14goproto_unrecognized\x12\x1f.google.protobuf.MessageOptions\x18\x9a\xf4\x03 \x01(\x08:5\n\nprotosizer\x12\x1f.google.protobuf.MessageOptions\x18\x9c\xf4\x03 \x01(\x08:2\n\x07\x63ompare\x12\x1f.google.protobuf.MessageOptions\x18\x9d\xf4\x03 \x01(\x08:3\n\x08typedecl\x12\x1f.google.protobuf.MessageOptions\x18\x9e\xf4\x03 \x01(\x08:6\n\x0bmessagename\x12\x1f.google.protobuf.MessageOptions\x18\xa1\xf4\x03 \x01(\x08:<\n\x11goproto_sizecache\x12\x1f.google.protobuf.MessageOptions\x18\xa2\xf4\x03 \x01(\x08::\n\x0fgoproto_unkeyed\x12\x1f.google.protobuf.MessageOptions\x18\xa3\xf4\x03 \x01(\x08:1\n\x08nullable\x12\x1d.google.protobuf.FieldOptions\x18\xe9\xfb\x03 \x01(\x08:.\n\x05\x65mbed\x12\x1d.google.protobuf.FieldOptions\x18\xea\xfb\x03 \x01(\x08:3\n\ncustomtype\x12\x1d.google.protobuf.FieldOptions\x18\xeb\xfb\x03 \x01(\t:3\n\ncustomname\x12\x1d.google.protobuf.FieldOptions\x18\xec\xfb\x03 \x01(\t:0\n\x07jsontag\x12\x1d.google.protobuf.FieldOptions\x18\xed\xfb\x03 \x01(\t:1\n\x08moretags\x12\x1d.google.protobuf.FieldOptions\x18\xee\xfb\x03 \x01(\t:1\n\x08\x63\x61sttype\x12\x1d.google.protobuf.FieldOptions\x18\xef\xfb\x03 \x01(\t:0\n\x07\x63\x61stkey\x12\x1d.google.protobuf.FieldOptions\x18\xf0\xfb\x03 \x01(\t:2\n\tcastvalue\x12\x1d.google.protobuf.FieldOptions\x18\xf1\xfb\x03 \x01(\t:0\n\x07stdtime\x12\x1d.google.protobuf.FieldOptions\x18\xf2\xfb\x03 \x01(\x08:4\n\x0bstdduration\x12\x1d.google.protobuf.FieldOptions\x18\xf3\xfb\x03 \x01(\x08:3\n\nwktpointer\x12\x1d.google.protobuf.FieldOptions\x18\xf4\xfb\x03 \x01(\x08:5\n\x0c\x63\x61strepeated\x12\x1d.google.protobuf.FieldOptions\x18\xf5\xfb\x03 \x01(\tBE\n\x13\x63om.google.protobufB\nGoGoProtosZ\"github.com/gogo/protobuf/gogoproto')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gogoproto.gogo_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.google.protobufB\nGoGoProtosZ\"github.com/gogo/protobuf/gogoproto'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/services/block/v1/block.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/services/block/v1/block.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.types.v1 import types_pb2 as cometbft_dot_types_dot_v1_dot_types__pb2
from cometbft.types.v1 import block_pb2 as cometbft_dot_types_dot_v1_dot_block__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cometbft/services/block/v1/block.proto\x12\x1a\x63ometbft.services.block.v1\x1a\x1d\x63ometbft/types/v1/types.proto\x1a\x1d\x63ometbft/types/v1/block.proto\"$\n\x12GetByHeightRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\"l\n\x13GetByHeightResponse\x12,\n\x08\x62lock_id\x18\x01 \x01(\x0b\x32\x1a.cometbft.types.v1.BlockID\x12\'\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x18.cometbft.types.v1.Block\"\x18\n\x16GetLatestHeightRequest\")\n\x17GetLatestHeightResponse\x12\x0e\n\x06height\x18\x01 \x01(\x03\x42=Z;github.com/cometbft/cometbft/api/cometbft/services/block/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.services.block.v1.block_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z;github.com/cometbft/cometbft/api/cometbft/services/block/v1'
  _globals['_GETBYHEIGHTREQUEST']._serialized_start=132
  _globals['_GETBYHEIGHTREQUEST']._serialized_end=168
  _globals['_GETBYHEIGHTRESPONSE']._serialized_start=170
  _globals['_GETBYHEIGHTRESPONSE']._serialized_end=278
  _globals['_GETLATESTHEIGHTREQUEST']._serialized_start=280
  _globals['_GETLATESTHEIGHTREQUEST']._serialized_end=304
  _globals['_GETLATESTHEIGHTRESPONSE']._serialized_start=306
  _globals['_GETLATESTHEIGHTRESPONSE']._serialized_end=347
# @@protoc_insertion_point(module_scope)



from abc import ABC, abstractmethod

from neurionpy.protos.cosmos.base.tendermint.v1beta1.query_pb2 import (
    GetBlockByHeightRequest,
    GetBlockByHeightResponse,
    GetLatestBlockRequest,
    GetLatestBlockResponse,
    GetLatestValidatorSetRequest,
    GetLatestValidatorSetResponse,
    GetNodeInfoRequest,
    GetNodeInfoResponse,
    GetSyncingRequest,
    GetSyncingResponse,
    GetValidatorSetByHeightRequest,
    GetValidatorSetByHeightResponse,
)


class CosmosBaseTendermint(ABC):
    """Cosmos Base Tendermint abstract class."""

    @abstractmethod
    def GetNodeInfo(self, request: GetNodeInfoRequest) -> GetNodeInfoResponse:
        """
        GetNodeInfo queries the current node info.

        :param request: GetNodeInfoRequest
        :return: GetNodeInfoResponse
        """

    @abstractmethod
    def GetSyncing(self, request: GetSyncingRequest) -> GetSyncingResponse:
        """
        GetSyncing queries node syncing.

        :param request: GetSyncingRequest
        :return: GetSyncingResponse
        """

    @abstractmethod
    def GetLatestBlock(self, request: GetLatestBlockRequest) -> GetLatestBlockResponse:
        """
        GetLatestBlock returns the latest block.

        :param request: GetLatestBlockRequest
        :return: GetLatestBlockResponse
        """

    @abstractmethod
    def GetBlockByHeight(
        self, request: GetBlockByHeightRequest
    ) -> GetBlockByHeightResponse:
        """
        GetBlockByHeight queries block for given height.

        :param request: GetBlockByHeightRequest
        :return: GetBlockByHeightResponse
        """

    @abstractmethod
    def GetLatestValidatorSet(
        self, request: GetLatestValidatorSetRequest
    ) -> GetLatestValidatorSetResponse:
        """
        GetLatestValidatorSet queries latest validator-set.

        :param request: GetLatestValidatorSetRequest
        :return: GetLatestValidatorSetResponse
        """

    @abstractmethod
    def GetValidatorSetByHeight(
        self, request: GetValidatorSetByHeightRequest
    ) -> GetValidatorSetByHeightResponse:
        """
        GetValidatorSetByHeight queries validator-set at a given height.

        :param request: GetValidatorSetByHeightRequest
        :return: GetValidatorSetByHeightResponse
        """



from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class DenomTrace(_message.Message):
    __slots__ = ("path", "base_denom")
    PATH_FIELD_NUMBER: _ClassVar[int]
    BASE_DENOM_FIELD_NUMBER: _ClassVar[int]
    path: str
    base_denom: str
    def __init__(self, path: _Optional[str] = ..., base_denom: _Optional[str] = ...) -> None: ...

class Params(_message.Message):
    __slots__ = ("send_enabled", "receive_enabled")
    SEND_ENABLED_FIELD_NUMBER: _ClassVar[int]
    RECEIVE_ENABLED_FIELD_NUMBER: _ClassVar[int]
    send_enabled: bool
    receive_enabled: bool
    def __init__(self, send_enabled: bool = ..., receive_enabled: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/privval/v1beta1/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/privval/v1beta1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.crypto.v1 import keys_pb2 as cometbft_dot_crypto_dot_v1_dot_keys__pb2
from cometbft.types.v1beta1 import types_pb2 as cometbft_dot_types_dot_v1beta1_dot_types__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cometbft/privval/v1beta1/types.proto\x12\x18\x63ometbft.privval.v1beta1\x1a\x1d\x63ometbft/crypto/v1/keys.proto\x1a\"cometbft/types/v1beta1/types.proto\x1a\x14gogoproto/gogo.proto\"6\n\x11RemoteSignerError\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"!\n\rPubKeyRequest\x12\x10\n\x08\x63hain_id\x18\x01 \x01(\t\"\x82\x01\n\x0ePubKeyResponse\x12\x34\n\x07pub_key\x18\x01 \x01(\x0b\x32\x1d.cometbft.crypto.v1.PublicKeyB\x04\xc8\xde\x1f\x00\x12:\n\x05\x65rror\x18\x02 \x01(\x0b\x32+.cometbft.privval.v1beta1.RemoteSignerError\"O\n\x0fSignVoteRequest\x12*\n\x04vote\x18\x01 \x01(\x0b\x32\x1c.cometbft.types.v1beta1.Vote\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\"\x82\x01\n\x12SignedVoteResponse\x12\x30\n\x04vote\x18\x01 \x01(\x0b\x32\x1c.cometbft.types.v1beta1.VoteB\x04\xc8\xde\x1f\x00\x12:\n\x05\x65rror\x18\x02 \x01(\x0b\x32+.cometbft.privval.v1beta1.RemoteSignerError\"[\n\x13SignProposalRequest\x12\x32\n\x08proposal\x18\x01 \x01(\x0b\x32 .cometbft.types.v1beta1.Proposal\x12\x10\n\x08\x63hain_id\x18\x02 \x01(\t\"\x8e\x01\n\x16SignedProposalResponse\x12\x38\n\x08proposal\x18\x01 \x01(\x0b\x32 .cometbft.types.v1beta1.ProposalB\x04\xc8\xde\x1f\x00\x12:\n\x05\x65rror\x18\x02 \x01(\x0b\x32+.cometbft.privval.v1beta1.RemoteSignerError\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\xd6\x04\n\x07Message\x12\x42\n\x0fpub_key_request\x18\x01 \x01(\x0b\x32\'.cometbft.privval.v1beta1.PubKeyRequestH\x00\x12\x44\n\x10pub_key_response\x18\x02 \x01(\x0b\x32(.cometbft.privval.v1beta1.PubKeyResponseH\x00\x12\x46\n\x11sign_vote_request\x18\x03 \x01(\x0b\x32).cometbft.privval.v1beta1.SignVoteRequestH\x00\x12L\n\x14signed_vote_response\x18\x04 \x01(\x0b\x32,.cometbft.privval.v1beta1.SignedVoteResponseH\x00\x12N\n\x15sign_proposal_request\x18\x05 \x01(\x0b\x32-.cometbft.privval.v1beta1.SignProposalRequestH\x00\x12T\n\x18signed_proposal_response\x18\x06 \x01(\x0b\x32\x30.cometbft.privval.v1beta1.SignedProposalResponseH\x00\x12=\n\x0cping_request\x18\x07 \x01(\x0b\x32%.cometbft.privval.v1beta1.PingRequestH\x00\x12?\n\rping_response\x18\x08 \x01(\x0b\x32&.cometbft.privval.v1beta1.PingResponseH\x00\x42\x05\n\x03sum*\xa8\x01\n\x06\x45rrors\x12\x12\n\x0e\x45RRORS_UNKNOWN\x10\x00\x12\x1e\n\x1a\x45RRORS_UNEXPECTED_RESPONSE\x10\x01\x12\x18\n\x14\x45RRORS_NO_CONNECTION\x10\x02\x12\x1d\n\x19\x45RRORS_CONNECTION_TIMEOUT\x10\x03\x12\x17\n\x13\x45RRORS_READ_TIMEOUT\x10\x04\x12\x18\n\x14\x45RRORS_WRITE_TIMEOUT\x10\x05\x42;Z9github.com/cometbft/cometbft/api/cometbft/privval/v1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.privval.v1beta1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/cometbft/cometbft/api/cometbft/privval/v1beta1'
  _globals['_PUBKEYRESPONSE'].fields_by_name['pub_key']._loaded_options = None
  _globals['_PUBKEYRESPONSE'].fields_by_name['pub_key']._serialized_options = b'\310\336\037\000'
  _globals['_SIGNEDVOTERESPONSE'].fields_by_name['vote']._loaded_options = None
  _globals['_SIGNEDVOTERESPONSE'].fields_by_name['vote']._serialized_options = b'\310\336\037\000'
  _globals['_SIGNEDPROPOSALRESPONSE'].fields_by_name['proposal']._loaded_options = None
  _globals['_SIGNEDPROPOSALRESPONSE'].fields_by_name['proposal']._serialized_options = b'\310\336\037\000'
  _globals['_ERRORS']._serialized_start=1464
  _globals['_ERRORS']._serialized_end=1632
  _globals['_REMOTESIGNERERROR']._serialized_start=155
  _globals['_REMOTESIGNERERROR']._serialized_end=209
  _globals['_PUBKEYREQUEST']._serialized_start=211
  _globals['_PUBKEYREQUEST']._serialized_end=244
  _globals['_PUBKEYRESPONSE']._serialized_start=247
  _globals['_PUBKEYRESPONSE']._serialized_end=377
  _globals['_SIGNVOTEREQUEST']._serialized_start=379
  _globals['_SIGNVOTEREQUEST']._serialized_end=458
  _globals['_SIGNEDVOTERESPONSE']._serialized_start=461
  _globals['_SIGNEDVOTERESPONSE']._serialized_end=591
  _globals['_SIGNPROPOSALREQUEST']._serialized_start=593
  _globals['_SIGNPROPOSALREQUEST']._serialized_end=684
  _globals['_SIGNEDPROPOSALRESPONSE']._serialized_start=687
  _globals['_SIGNEDPROPOSALRESPONSE']._serialized_end=829
  _globals['_PINGREQUEST']._serialized_start=831
  _globals['_PINGREQUEST']._serialized_end=844
  _globals['_PINGRESPONSE']._serialized_start=846
  _globals['_PINGRESPONSE']._serialized_end=860
  _globals['_MESSAGE']._serialized_start=863
  _globals['_MESSAGE']._serialized_end=1461
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/distribution/v1beta1/query.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/distribution/v1beta1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.distribution.v1beta1 import distribution_pb2 as cosmos_dot_distribution_dot_v1beta1_dot_distribution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'cosmos/distribution/v1beta1/query.proto\x12\x1b\x63osmos.distribution.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a.cosmos/distribution/v1beta1/distribution.proto\"\x14\n\x12QueryParamsRequest\"P\n\x13QueryParamsResponse\x12\x39\n\x06params\x18\x01 \x01(\x0b\x32#.cosmos.distribution.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\"D\n\'QueryValidatorOutstandingRewardsRequest\x12\x19\n\x11validator_address\x18\x01 \x01(\t\"{\n(QueryValidatorOutstandingRewardsResponse\x12O\n\x07rewards\x18\x01 \x01(\x0b\x32\x38.cosmos.distribution.v1beta1.ValidatorOutstandingRewardsB\x04\xc8\xde\x1f\x00\"<\n\x1fQueryValidatorCommissionRequest\x12\x19\n\x11validator_address\x18\x01 \x01(\t\"y\n QueryValidatorCommissionResponse\x12U\n\ncommission\x18\x01 \x01(\x0b\x32;.cosmos.distribution.v1beta1.ValidatorAccumulatedCommissionB\x04\xc8\xde\x1f\x00\"\xaf\x01\n\x1cQueryValidatorSlashesRequest\x12\x19\n\x11validator_address\x18\x01 \x01(\t\x12\x17\n\x0fstarting_height\x18\x02 \x01(\x04\x12\x15\n\rending_height\x18\x03 \x01(\x04\x12:\n\npagination\x18\x04 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x01\"\xa5\x01\n\x1dQueryValidatorSlashesResponse\x12G\n\x07slashes\x18\x01 \x03(\x0b\x32\x30.cosmos.distribution.v1beta1.ValidatorSlashEventB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"_\n\x1dQueryDelegationRewardsRequest\x12\x19\n\x11\x64\x65legator_address\x18\x01 \x01(\t\x12\x19\n\x11validator_address\x18\x02 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x84\x01\n\x1eQueryDelegationRewardsResponse\x12\x62\n\x07rewards\x18\x01 \x03(\x0b\x32\x1c.cosmos.base.v1beta1.DecCoinB3\xc8\xde\x1f\x00\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\"I\n\"QueryDelegationTotalRewardsRequest\x12\x19\n\x11\x64\x65legator_address\x18\x01 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xd6\x01\n#QueryDelegationTotalRewardsResponse\x12M\n\x07rewards\x18\x01 \x03(\x0b\x32\x36.cosmos.distribution.v1beta1.DelegationDelegatorRewardB\x04\xc8\xde\x1f\x00\x12`\n\x05total\x18\x02 \x03(\x0b\x32\x1c.cosmos.base.v1beta1.DecCoinB3\xc8\xde\x1f\x00\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins\"F\n\x1fQueryDelegatorValidatorsRequest\x12\x19\n\x11\x64\x65legator_address\x18\x01 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"@\n QueryDelegatorValidatorsResponse\x12\x12\n\nvalidators\x18\x01 \x03(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"K\n$QueryDelegatorWithdrawAddressRequest\x12\x19\n\x11\x64\x65legator_address\x18\x01 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"K\n%QueryDelegatorWithdrawAddressResponse\x12\x18\n\x10withdraw_address\x18\x01 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x1b\n\x19QueryCommunityPoolRequest\"}\n\x1aQueryCommunityPoolResponse\x12_\n\x04pool\x18\x01 \x03(\x0b\x32\x1c.cosmos.base.v1beta1.DecCoinB3\xc8\xde\x1f\x00\xaa\xdf\x1f+github.com/cosmos/cosmos-sdk/types.DecCoins2\xd8\x0f\n\x05Query\x12\x98\x01\n\x06Params\x12/.cosmos.distribution.v1beta1.QueryParamsRequest\x1a\x30.cosmos.distribution.v1beta1.QueryParamsResponse\"+\x82\xd3\xe4\x93\x02%\x12#/cosmos/distribution/v1beta1/params\x12\x83\x02\n\x1bValidatorOutstandingRewards\x12\x44.cosmos.distribution.v1beta1.QueryValidatorOutstandingRewardsRequest\x1a\x45.cosmos.distribution.v1beta1.QueryValidatorOutstandingRewardsResponse\"W\x82\xd3\xe4\x93\x02Q\x12O/cosmos/distribution/v1beta1/validators/{validator_address}/outstanding_rewards\x12\xe2\x01\n\x13ValidatorCommission\x12<.cosmos.distribution.v1beta1.QueryValidatorCommissionRequest\x1a=.cosmos.distribution.v1beta1.QueryValidatorCommissionResponse\"N\x82\xd3\xe4\x93\x02H\x12\x46/cosmos/distribution/v1beta1/validators/{validator_address}/commission\x12\xd6\x01\n\x10ValidatorSlashes\x12\x39.cosmos.distribution.v1beta1.QueryValidatorSlashesRequest\x1a:.cosmos.distribution.v1beta1.QueryValidatorSlashesResponse\"K\x82\xd3\xe4\x93\x02\x45\x12\x43/cosmos/distribution/v1beta1/validators/{validator_address}/slashes\x12\xed\x01\n\x11\x44\x65legationRewards\x12:.cosmos.distribution.v1beta1.QueryDelegationRewardsRequest\x1a;.cosmos.distribution.v1beta1.QueryDelegationRewardsResponse\"_\x82\xd3\xe4\x93\x02Y\x12W/cosmos/distribution/v1beta1/delegators/{delegator_address}/rewards/{validator_address}\x12\xe8\x01\n\x16\x44\x65legationTotalRewards\x12?.cosmos.distribution.v1beta1.QueryDelegationTotalRewardsRequest\x1a@.cosmos.distribution.v1beta1.QueryDelegationTotalRewardsResponse\"K\x82\xd3\xe4\x93\x02\x45\x12\x43/cosmos/distribution/v1beta1/delegators/{delegator_address}/rewards\x12\xe2\x01\n\x13\x44\x65legatorValidators\x12<.cosmos.distribution.v1beta1.QueryDelegatorValidatorsRequest\x1a=.cosmos.distribution.v1beta1.QueryDelegatorValidatorsResponse\"N\x82\xd3\xe4\x93\x02H\x12\x46/cosmos/distribution/v1beta1/delegators/{delegator_address}/validators\x12\xf7\x01\n\x18\x44\x65legatorWithdrawAddress\x12\x41.cosmos.distribution.v1beta1.QueryDelegatorWithdrawAddressRequest\x1a\x42.cosmos.distribution.v1beta1.QueryDelegatorWithdrawAddressResponse\"T\x82\xd3\xe4\x93\x02N\x12L/cosmos/distribution/v1beta1/delegators/{delegator_address}/withdraw_address\x12\xb5\x01\n\rCommunityPool\x12\x36.cosmos.distribution.v1beta1.QueryCommunityPoolRequest\x1a\x37.cosmos.distribution.v1beta1.QueryCommunityPoolResponse\"3\x82\xd3\xe4\x93\x02-\x12+/cosmos/distribution/v1beta1/community_poolB3Z1github.com/cosmos/cosmos-sdk/x/distribution/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.distribution.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/distribution/types'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVALIDATOROUTSTANDINGREWARDSRESPONSE'].fields_by_name['rewards']._loaded_options = None
  _globals['_QUERYVALIDATOROUTSTANDINGREWARDSRESPONSE'].fields_by_name['rewards']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVALIDATORCOMMISSIONRESPONSE'].fields_by_name['commission']._loaded_options = None
  _globals['_QUERYVALIDATORCOMMISSIONRESPONSE'].fields_by_name['commission']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVALIDATORSLASHESREQUEST']._loaded_options = None
  _globals['_QUERYVALIDATORSLASHESREQUEST']._serialized_options = b'\210\240\037\000\230\240\037\001'
  _globals['_QUERYVALIDATORSLASHESRESPONSE'].fields_by_name['slashes']._loaded_options = None
  _globals['_QUERYVALIDATORSLASHESRESPONSE'].fields_by_name['slashes']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYDELEGATIONREWARDSREQUEST']._loaded_options = None
  _globals['_QUERYDELEGATIONREWARDSREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYDELEGATIONREWARDSRESPONSE'].fields_by_name['rewards']._loaded_options = None
  _globals['_QUERYDELEGATIONREWARDSRESPONSE'].fields_by_name['rewards']._serialized_options = b'\310\336\037\000\252\337\037+github.com/cosmos/cosmos-sdk/types.DecCoins'
  _globals['_QUERYDELEGATIONTOTALREWARDSREQUEST']._loaded_options = None
  _globals['_QUERYDELEGATIONTOTALREWARDSREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYDELEGATIONTOTALREWARDSRESPONSE'].fields_by_name['rewards']._loaded_options = None
  _globals['_QUERYDELEGATIONTOTALREWARDSRESPONSE'].fields_by_name['rewards']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYDELEGATIONTOTALREWARDSRESPONSE'].fields_by_name['total']._loaded_options = None
  _globals['_QUERYDELEGATIONTOTALREWARDSRESPONSE'].fields_by_name['total']._serialized_options = b'\310\336\037\000\252\337\037+github.com/cosmos/cosmos-sdk/types.DecCoins'
  _globals['_QUERYDELEGATORVALIDATORSREQUEST']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORSREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYDELEGATORVALIDATORSRESPONSE']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORSRESPONSE']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYDELEGATORWITHDRAWADDRESSREQUEST']._loaded_options = None
  _globals['_QUERYDELEGATORWITHDRAWADDRESSREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYDELEGATORWITHDRAWADDRESSRESPONSE']._loaded_options = None
  _globals['_QUERYDELEGATORWITHDRAWADDRESSRESPONSE']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYCOMMUNITYPOOLRESPONSE'].fields_by_name['pool']._loaded_options = None
  _globals['_QUERYCOMMUNITYPOOLRESPONSE'].fields_by_name['pool']._serialized_options = b'\310\336\037\000\252\337\037+github.com/cosmos/cosmos-sdk/types.DecCoins'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002%\022#/cosmos/distribution/v1beta1/params'
  _globals['_QUERY'].methods_by_name['ValidatorOutstandingRewards']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ValidatorOutstandingRewards']._serialized_options = b'\202\323\344\223\002Q\022O/cosmos/distribution/v1beta1/validators/{validator_address}/outstanding_rewards'
  _globals['_QUERY'].methods_by_name['ValidatorCommission']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ValidatorCommission']._serialized_options = b'\202\323\344\223\002H\022F/cosmos/distribution/v1beta1/validators/{validator_address}/commission'
  _globals['_QUERY'].methods_by_name['ValidatorSlashes']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ValidatorSlashes']._serialized_options = b'\202\323\344\223\002E\022C/cosmos/distribution/v1beta1/validators/{validator_address}/slashes'
  _globals['_QUERY'].methods_by_name['DelegationRewards']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DelegationRewards']._serialized_options = b'\202\323\344\223\002Y\022W/cosmos/distribution/v1beta1/delegators/{delegator_address}/rewards/{validator_address}'
  _globals['_QUERY'].methods_by_name['DelegationTotalRewards']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DelegationTotalRewards']._serialized_options = b'\202\323\344\223\002E\022C/cosmos/distribution/v1beta1/delegators/{delegator_address}/rewards'
  _globals['_QUERY'].methods_by_name['DelegatorValidators']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DelegatorValidators']._serialized_options = b'\202\323\344\223\002H\022F/cosmos/distribution/v1beta1/delegators/{delegator_address}/validators'
  _globals['_QUERY'].methods_by_name['DelegatorWithdrawAddress']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DelegatorWithdrawAddress']._serialized_options = b'\202\323\344\223\002N\022L/cosmos/distribution/v1beta1/delegators/{delegator_address}/withdraw_address'
  _globals['_QUERY'].methods_by_name['CommunityPool']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CommunityPool']._serialized_options = b'\202\323\344\223\002-\022+/cosmos/distribution/v1beta1/community_pool'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=248
  _globals['_QUERYPARAMSREQUEST']._serialized_end=268
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=270
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=350
  _globals['_QUERYVALIDATOROUTSTANDINGREWARDSREQUEST']._serialized_start=352
  _globals['_QUERYVALIDATOROUTSTANDINGREWARDSREQUEST']._serialized_end=420
  _globals['_QUERYVALIDATOROUTSTANDINGREWARDSRESPONSE']._serialized_start=422
  _globals['_QUERYVALIDATOROUTSTANDINGREWARDSRESPONSE']._serialized_end=545
  _globals['_QUERYVALIDATORCOMMISSIONREQUEST']._serialized_start=547
  _globals['_QUERYVALIDATORCOMMISSIONREQUEST']._serialized_end=607
  _globals['_QUERYVALIDATORCOMMISSIONRESPONSE']._serialized_start=609
  _globals['_QUERYVALIDATORCOMMISSIONRESPONSE']._serialized_end=730
  _globals['_QUERYVALIDATORSLASHESREQUEST']._serialized_start=733
  _globals['_QUERYVALIDATORSLASHESREQUEST']._serialized_end=908
  _globals['_QUERYVALIDATORSLASHESRESPONSE']._serialized_start=911
  _globals['_QUERYVALIDATORSLASHESRESPONSE']._serialized_end=1076
  _globals['_QUERYDELEGATIONREWARDSREQUEST']._serialized_start=1078
  _globals['_QUERYDELEGATIONREWARDSREQUEST']._serialized_end=1173
  _globals['_QUERYDELEGATIONREWARDSRESPONSE']._serialized_start=1176
  _globals['_QUERYDELEGATIONREWARDSRESPONSE']._serialized_end=1308
  _globals['_QUERYDELEGATIONTOTALREWARDSREQUEST']._serialized_start=1310
  _globals['_QUERYDELEGATIONTOTALREWARDSREQUEST']._serialized_end=1383
  _globals['_QUERYDELEGATIONTOTALREWARDSRESPONSE']._serialized_start=1386
  _globals['_QUERYDELEGATIONTOTALREWARDSRESPONSE']._serialized_end=1600
  _globals['_QUERYDELEGATORVALIDATORSREQUEST']._serialized_start=1602
  _globals['_QUERYDELEGATORVALIDATORSREQUEST']._serialized_end=1672
  _globals['_QUERYDELEGATORVALIDATORSRESPONSE']._serialized_start=1674
  _globals['_QUERYDELEGATORVALIDATORSRESPONSE']._serialized_end=1738
  _globals['_QUERYDELEGATORWITHDRAWADDRESSREQUEST']._serialized_start=1740
  _globals['_QUERYDELEGATORWITHDRAWADDRESSREQUEST']._serialized_end=1815
  _globals['_QUERYDELEGATORWITHDRAWADDRESSRESPONSE']._serialized_start=1817
  _globals['_QUERYDELEGATORWITHDRAWADDRESSRESPONSE']._serialized_end=1892
  _globals['_QUERYCOMMUNITYPOOLREQUEST']._serialized_start=1894
  _globals['_QUERYCOMMUNITYPOOLREQUEST']._serialized_end=1921
  _globals['_QUERYCOMMUNITYPOOLRESPONSE']._serialized_start=1923
  _globals['_QUERYCOMMUNITYPOOLRESPONSE']._serialized_end=2048
  _globals['_QUERY']._serialized_start=2051
  _globals['_QUERY']._serialized_end=4059
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/base/reflection/v2alpha1/reflection.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/base/reflection/v2alpha1/reflection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0cosmos/base/reflection/v2alpha1/reflection.proto\x12\x1f\x63osmos.base.reflection.v2alpha1\x1a\x1cgoogle/api/annotations.proto\"\xb0\x03\n\rAppDescriptor\x12?\n\x05\x61uthn\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.AuthnDescriptor\x12?\n\x05\x63hain\x18\x02 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.ChainDescriptor\x12?\n\x05\x63odec\x18\x03 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.CodecDescriptor\x12O\n\rconfiguration\x18\x04 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.ConfigurationDescriptor\x12P\n\x0equery_services\x18\x05 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.QueryServicesDescriptor\x12\x39\n\x02tx\x18\x06 \x01(\x0b\x32-.cosmos.base.reflection.v2alpha1.TxDescriptor\"^\n\x0cTxDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12<\n\x04msgs\x18\x02 \x03(\x0b\x32..cosmos.base.reflection.v2alpha1.MsgDescriptor\"]\n\x0f\x41uthnDescriptor\x12J\n\nsign_modes\x18\x01 \x03(\x0b\x32\x36.cosmos.base.reflection.v2alpha1.SigningModeDescriptor\"b\n\x15SigningModeDescriptor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\x05\x12+\n#authn_info_provider_method_fullname\x18\x03 \x01(\t\"\x1d\n\x0f\x43hainDescriptor\x12\n\n\x02id\x18\x01 \x01(\t\"[\n\x0f\x43odecDescriptor\x12H\n\ninterfaces\x18\x01 \x03(\x0b\x32\x34.cosmos.base.reflection.v2alpha1.InterfaceDescriptor\"\xf4\x01\n\x13InterfaceDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12j\n\x1cinterface_accepting_messages\x18\x02 \x03(\x0b\x32\x44.cosmos.base.reflection.v2alpha1.InterfaceAcceptingMessageDescriptor\x12_\n\x16interface_implementers\x18\x03 \x03(\x0b\x32?.cosmos.base.reflection.v2alpha1.InterfaceImplementerDescriptor\"D\n\x1eInterfaceImplementerDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12\x10\n\x08type_url\x18\x02 \x01(\t\"W\n#InterfaceAcceptingMessageDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12\x1e\n\x16\x66ield_descriptor_names\x18\x02 \x03(\t\"@\n\x17\x43onfigurationDescriptor\x12%\n\x1d\x62\x65\x63h32_account_address_prefix\x18\x01 \x01(\t\"%\n\rMsgDescriptor\x12\x14\n\x0cmsg_type_url\x18\x01 \x01(\t\"\x1b\n\x19GetAuthnDescriptorRequest\"]\n\x1aGetAuthnDescriptorResponse\x12?\n\x05\x61uthn\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.AuthnDescriptor\"\x1b\n\x19GetChainDescriptorRequest\"]\n\x1aGetChainDescriptorResponse\x12?\n\x05\x63hain\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.ChainDescriptor\"\x1b\n\x19GetCodecDescriptorRequest\"]\n\x1aGetCodecDescriptorResponse\x12?\n\x05\x63odec\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.CodecDescriptor\"#\n!GetConfigurationDescriptorRequest\"n\n\"GetConfigurationDescriptorResponse\x12H\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.ConfigurationDescriptor\"#\n!GetQueryServicesDescriptorRequest\"o\n\"GetQueryServicesDescriptorResponse\x12I\n\x07queries\x18\x01 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.QueryServicesDescriptor\"\x18\n\x16GetTxDescriptorRequest\"T\n\x17GetTxDescriptorResponse\x12\x39\n\x02tx\x18\x01 \x01(\x0b\x32-.cosmos.base.reflection.v2alpha1.TxDescriptor\"j\n\x17QueryServicesDescriptor\x12O\n\x0equery_services\x18\x01 \x03(\x0b\x32\x37.cosmos.base.reflection.v2alpha1.QueryServiceDescriptor\"\x86\x01\n\x16QueryServiceDescriptor\x12\x10\n\x08\x66ullname\x18\x01 \x01(\t\x12\x11\n\tis_module\x18\x02 \x01(\x08\x12G\n\x07methods\x18\x03 \x03(\x0b\x32\x36.cosmos.base.reflection.v2alpha1.QueryMethodDescriptor\">\n\x15QueryMethodDescriptor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0f\x66ull_query_path\x18\x02 \x01(\t2\xa7\n\n\x11ReflectionService\x12\xcb\x01\n\x12GetAuthnDescriptor\x12:.cosmos.base.reflection.v2alpha1.GetAuthnDescriptorRequest\x1a;.cosmos.base.reflection.v2alpha1.GetAuthnDescriptorResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/base/reflection/v1beta1/app_descriptor/authn\x12\xcb\x01\n\x12GetChainDescriptor\x12:.cosmos.base.reflection.v2alpha1.GetChainDescriptorRequest\x1a;.cosmos.base.reflection.v2alpha1.GetChainDescriptorResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/base/reflection/v1beta1/app_descriptor/chain\x12\xcb\x01\n\x12GetCodecDescriptor\x12:.cosmos.base.reflection.v2alpha1.GetCodecDescriptorRequest\x1a;.cosmos.base.reflection.v2alpha1.GetCodecDescriptorResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/base/reflection/v1beta1/app_descriptor/codec\x12\xeb\x01\n\x1aGetConfigurationDescriptor\x12\x42.cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorRequest\x1a\x43.cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorResponse\"D\x82\xd3\xe4\x93\x02>\x12</cosmos/base/reflection/v1beta1/app_descriptor/configuration\x12\xec\x01\n\x1aGetQueryServicesDescriptor\x12\x42.cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorRequest\x1a\x43.cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorResponse\"E\x82\xd3\xe4\x93\x02?\x12=/cosmos/base/reflection/v1beta1/app_descriptor/query_services\x12\xca\x01\n\x0fGetTxDescriptor\x12\x37.cosmos.base.reflection.v2alpha1.GetTxDescriptorRequest\x1a\x38.cosmos.base.reflection.v2alpha1.GetTxDescriptorResponse\"D\x82\xd3\xe4\x93\x02>\x12</cosmos/base/reflection/v1beta1/app_descriptor/tx_descriptorB>Z<github.com/cosmos/cosmos-sdk/server/grpc/reflection/v2alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.reflection.v2alpha1.reflection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/cosmos/cosmos-sdk/server/grpc/reflection/v2alpha1'
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetAuthnDescriptor']._loaded_options = None
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetAuthnDescriptor']._serialized_options = b'\202\323\344\223\0026\0224/cosmos/base/reflection/v1beta1/app_descriptor/authn'
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetChainDescriptor']._loaded_options = None
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetChainDescriptor']._serialized_options = b'\202\323\344\223\0026\0224/cosmos/base/reflection/v1beta1/app_descriptor/chain'
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetCodecDescriptor']._loaded_options = None
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetCodecDescriptor']._serialized_options = b'\202\323\344\223\0026\0224/cosmos/base/reflection/v1beta1/app_descriptor/codec'
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetConfigurationDescriptor']._loaded_options = None
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetConfigurationDescriptor']._serialized_options = b'\202\323\344\223\002>\022</cosmos/base/reflection/v1beta1/app_descriptor/configuration'
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetQueryServicesDescriptor']._loaded_options = None
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetQueryServicesDescriptor']._serialized_options = b'\202\323\344\223\002?\022=/cosmos/base/reflection/v1beta1/app_descriptor/query_services'
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetTxDescriptor']._loaded_options = None
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetTxDescriptor']._serialized_options = b'\202\323\344\223\002>\022</cosmos/base/reflection/v1beta1/app_descriptor/tx_descriptor'
  _globals['_APPDESCRIPTOR']._serialized_start=116
  _globals['_APPDESCRIPTOR']._serialized_end=548
  _globals['_TXDESCRIPTOR']._serialized_start=550
  _globals['_TXDESCRIPTOR']._serialized_end=644
  _globals['_AUTHNDESCRIPTOR']._serialized_start=646
  _globals['_AUTHNDESCRIPTOR']._serialized_end=739
  _globals['_SIGNINGMODEDESCRIPTOR']._serialized_start=741
  _globals['_SIGNINGMODEDESCRIPTOR']._serialized_end=839
  _globals['_CHAINDESCRIPTOR']._serialized_start=841
  _globals['_CHAINDESCRIPTOR']._serialized_end=870
  _globals['_CODECDESCRIPTOR']._serialized_start=872
  _globals['_CODECDESCRIPTOR']._serialized_end=963
  _globals['_INTERFACEDESCRIPTOR']._serialized_start=966
  _globals['_INTERFACEDESCRIPTOR']._serialized_end=1210
  _globals['_INTERFACEIMPLEMENTERDESCRIPTOR']._serialized_start=1212
  _globals['_INTERFACEIMPLEMENTERDESCRIPTOR']._serialized_end=1280
  _globals['_INTERFACEACCEPTINGMESSAGEDESCRIPTOR']._serialized_start=1282
  _globals['_INTERFACEACCEPTINGMESSAGEDESCRIPTOR']._serialized_end=1369
  _globals['_CONFIGURATIONDESCRIPTOR']._serialized_start=1371
  _globals['_CONFIGURATIONDESCRIPTOR']._serialized_end=1435
  _globals['_MSGDESCRIPTOR']._serialized_start=1437
  _globals['_MSGDESCRIPTOR']._serialized_end=1474
  _globals['_GETAUTHNDESCRIPTORREQUEST']._serialized_start=1476
  _globals['_GETAUTHNDESCRIPTORREQUEST']._serialized_end=1503
  _globals['_GETAUTHNDESCRIPTORRESPONSE']._serialized_start=1505
  _globals['_GETAUTHNDESCRIPTORRESPONSE']._serialized_end=1598
  _globals['_GETCHAINDESCRIPTORREQUEST']._serialized_start=1600
  _globals['_GETCHAINDESCRIPTORREQUEST']._serialized_end=1627
  _globals['_GETCHAINDESCRIPTORRESPONSE']._serialized_start=1629
  _globals['_GETCHAINDESCRIPTORRESPONSE']._serialized_end=1722
  _globals['_GETCODECDESCRIPTORREQUEST']._serialized_start=1724
  _globals['_GETCODECDESCRIPTORREQUEST']._serialized_end=1751
  _globals['_GETCODECDESCRIPTORRESPONSE']._serialized_start=1753
  _globals['_GETCODECDESCRIPTORRESPONSE']._serialized_end=1846
  _globals['_GETCONFIGURATIONDESCRIPTORREQUEST']._serialized_start=1848
  _globals['_GETCONFIGURATIONDESCRIPTORREQUEST']._serialized_end=1883
  _globals['_GETCONFIGURATIONDESCRIPTORRESPONSE']._serialized_start=1885
  _globals['_GETCONFIGURATIONDESCRIPTORRESPONSE']._serialized_end=1995
  _globals['_GETQUERYSERVICESDESCRIPTORREQUEST']._serialized_start=1997
  _globals['_GETQUERYSERVICESDESCRIPTORREQUEST']._serialized_end=2032
  _globals['_GETQUERYSERVICESDESCRIPTORRESPONSE']._serialized_start=2034
  _globals['_GETQUERYSERVICESDESCRIPTORRESPONSE']._serialized_end=2145
  _globals['_GETTXDESCRIPTORREQUEST']._serialized_start=2147
  _globals['_GETTXDESCRIPTORREQUEST']._serialized_end=2171
  _globals['_GETTXDESCRIPTORRESPONSE']._serialized_start=2173
  _globals['_GETTXDESCRIPTORRESPONSE']._serialized_end=2257
  _globals['_QUERYSERVICESDESCRIPTOR']._serialized_start=2259
  _globals['_QUERYSERVICESDESCRIPTOR']._serialized_end=2365
  _globals['_QUERYSERVICEDESCRIPTOR']._serialized_start=2368
  _globals['_QUERYSERVICEDESCRIPTOR']._serialized_end=2502
  _globals['_QUERYMETHODDESCRIPTOR']._serialized_start=2504
  _globals['_QUERYMETHODDESCRIPTOR']._serialized_end=2566
  _globals['_REFLECTIONSERVICE']._serialized_start=2569
  _globals['_REFLECTIONSERVICE']._serialized_end=3888
# @@protoc_insertion_point(module_scope)



from amino import amino_pb2 as _amino_pb2
from cosmos.msg.v1 import msg_pb2 as _msg_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from neurion.fusion import params_pb2 as _params_pb2
from neurion.fusion import task_pb2 as _task_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgUpdateParams(_message.Message):
    __slots__ = ("authority", "params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    params: _params_pb2.Params
    def __init__(self, authority: _Optional[str] = ..., params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...

class MsgUpdateParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgApplyCreator(_message.Message):
    __slots__ = ("creator", "description")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    creator: str
    description: str
    def __init__(self, creator: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class MsgApplyCreatorResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgApproveApplication(_message.Message):
    __slots__ = ("creator", "application_id", "reason")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_ID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    creator: str
    application_id: int
    reason: str
    def __init__(self, creator: _Optional[str] = ..., application_id: _Optional[int] = ..., reason: _Optional[str] = ...) -> None: ...

class MsgApproveApplicationResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgRejectApplication(_message.Message):
    __slots__ = ("creator", "application_id", "reason")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_ID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    creator: str
    application_id: int
    reason: str
    def __init__(self, creator: _Optional[str] = ..., application_id: _Optional[int] = ..., reason: _Optional[str] = ...) -> None: ...

class MsgRejectApplicationResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgCreateTask(_message.Message):
    __slots__ = ("creator", "base_model", "max_rounds", "reward", "name", "description")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    BASE_MODEL_FIELD_NUMBER: _ClassVar[int]
    MAX_ROUNDS_FIELD_NUMBER: _ClassVar[int]
    REWARD_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    creator: str
    base_model: str
    max_rounds: int
    reward: int
    name: str
    description: str
    def __init__(self, creator: _Optional[str] = ..., base_model: _Optional[str] = ..., max_rounds: _Optional[int] = ..., reward: _Optional[int] = ..., name: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class MsgCreateTaskResponse(_message.Message):
    __slots__ = ("task",)
    TASK_FIELD_NUMBER: _ClassVar[int]
    task: _task_pb2.Task
    def __init__(self, task: _Optional[_Union[_task_pb2.Task, _Mapping]] = ...) -> None: ...

class MsgStartTask(_message.Message):
    __slots__ = ("creator", "task_id")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    creator: str
    task_id: int
    def __init__(self, creator: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class MsgStartTaskResponse(_message.Message):
    __slots__ = ("task",)
    TASK_FIELD_NUMBER: _ClassVar[int]
    task: _task_pb2.Task
    def __init__(self, task: _Optional[_Union[_task_pb2.Task, _Mapping]] = ...) -> None: ...

class MsgProposeModel(_message.Message):
    __slots__ = ("creator", "task_id", "model", "metainfo", "round")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    METAINFO_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    creator: str
    task_id: int
    model: str
    metainfo: str
    round: int
    def __init__(self, creator: _Optional[str] = ..., task_id: _Optional[int] = ..., model: _Optional[str] = ..., metainfo: _Optional[str] = ..., round: _Optional[int] = ...) -> None: ...

class MsgProposeModelResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgRegisterProposer(_message.Message):
    __slots__ = ("creator", "stake", "task_id")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    STAKE_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    creator: str
    stake: int
    task_id: int
    def __init__(self, creator: _Optional[str] = ..., stake: _Optional[int] = ..., task_id: _Optional[int] = ...) -> None: ...

class MsgRegisterProposerResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgRegisterValidator(_message.Message):
    __slots__ = ("creator", "stake", "task_id")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    STAKE_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    creator: str
    stake: int
    task_id: int
    def __init__(self, creator: _Optional[str] = ..., stake: _Optional[int] = ..., task_id: _Optional[int] = ...) -> None: ...

class MsgRegisterValidatorResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgStartTesting(_message.Message):
    __slots__ = ("creator", "round", "testset", "task_id")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    TESTSET_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    creator: str
    round: int
    testset: str
    task_id: int
    def __init__(self, creator: _Optional[str] = ..., round: _Optional[int] = ..., testset: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class MsgStartTestingResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgRequestValidationTask(_message.Message):
    __slots__ = ("creator", "task_id")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    creator: str
    task_id: int
    def __init__(self, creator: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class MsgRequestValidationTaskResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgSubmitScore(_message.Message):
    __slots__ = ("creator", "validation_task_id", "score")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    VALIDATION_TASK_ID_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    creator: str
    validation_task_id: int
    score: str
    def __init__(self, creator: _Optional[str] = ..., validation_task_id: _Optional[int] = ..., score: _Optional[str] = ...) -> None: ...

class MsgSubmitScoreResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgDisputeModelScore(_message.Message):
    __slots__ = ("creator", "model_id", "score")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    creator: str
    model_id: int
    score: str
    def __init__(self, creator: _Optional[str] = ..., model_id: _Optional[int] = ..., score: _Optional[str] = ...) -> None: ...

class MsgDisputeModelScoreResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgStartNewRound(_message.Message):
    __slots__ = ("creator", "round", "base_model", "task_id")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    BASE_MODEL_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    creator: str
    round: int
    base_model: str
    task_id: int
    def __init__(self, creator: _Optional[str] = ..., round: _Optional[int] = ..., base_model: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class MsgStartNewRoundResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgTerminateTask(_message.Message):
    __slots__ = ("creator", "task_id")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    creator: str
    task_id: int
    def __init__(self, creator: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class MsgTerminateTaskResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgStakeToTask(_message.Message):
    __slots__ = ("creator", "task_id", "amount")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    creator: str
    task_id: int
    amount: int
    def __init__(self, creator: _Optional[str] = ..., task_id: _Optional[int] = ..., amount: _Optional[int] = ...) -> None: ...

class MsgStakeToTaskResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgClaimTaskReward(_message.Message):
    __slots__ = ("creator", "task_id")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    creator: str
    task_id: int
    def __init__(self, creator: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class MsgClaimTaskRewardResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUnstakeFromTask(_message.Message):
    __slots__ = ("creator", "task_id")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    creator: str
    task_id: int
    def __init__(self, creator: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class MsgUnstakeFromTaskResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgDisclaimCreatorStatus(_message.Message):
    __slots__ = ("creator", "reason")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    creator: str
    reason: str
    def __init__(self, creator: _Optional[str] = ..., reason: _Optional[str] = ...) -> None: ...

class MsgDisclaimCreatorStatusResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgAbortTask(_message.Message):
    __slots__ = ("creator", "task_id")
    CREATOR_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    creator: str
    task_id: int
    def __init__(self, creator: _Optional[str] = ..., task_id: _Optional[int] = ...) -> None: ...

class MsgAbortTaskResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class BlockStoreState(_message.Message):
    __slots__ = ("base", "height")
    BASE_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    base: int
    height: int
    def __init__(self, base: _Optional[int] = ..., height: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/ganglion/pathway_user.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/ganglion/pathway_user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#neurion/ganglion/pathway_user.proto\x12\x10neurion.ganglion\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\"\'\n\x0bPathwayUser\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0c\n\x04user\x18\x02 \x01(\tB\x1aZ\x18neurion/x/ganglion/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.ganglion.pathway_user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\030neurion/x/ganglion/types'
  _globals['_PATHWAYUSER']._serialized_start=106
  _globals['_PATHWAYUSER']._serialized_end=145
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/services/version/v1/version.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/services/version/v1/version.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cometbft/services/version/v1/version.proto\x12\x1c\x63ometbft.services.version.v1\"\x13\n\x11GetVersionRequest\"L\n\x12GetVersionResponse\x12\x0c\n\x04node\x18\x01 \x01(\t\x12\x0c\n\x04\x61\x62\x63i\x18\x02 \x01(\t\x12\x0b\n\x03p2p\x18\x03 \x01(\x04\x12\r\n\x05\x62lock\x18\x04 \x01(\x04\x42?Z=github.com/cometbft/cometbft/api/cometbft/services/version/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.services.version.v1.version_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/cometbft/cometbft/api/cometbft/services/version/v1'
  _globals['_GETVERSIONREQUEST']._serialized_start=76
  _globals['_GETVERSIONREQUEST']._serialized_end=95
  _globals['_GETVERSIONRESPONSE']._serialized_start=97
  _globals['_GETVERSIONRESPONSE']._serialized_end=173
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class EventDataRoundState(_message.Message):
    __slots__ = ("height", "round", "step")
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    STEP_FIELD_NUMBER: _ClassVar[int]
    height: int
    round: int
    step: str
    def __init__(self, height: _Optional[int] = ..., round: _Optional[int] = ..., step: _Optional[str] = ...) -> None: ...




from google.protobuf.json_format import Parse

from neurionpy.common.rest_client import RestClient
from neurionpy.evidence.interface import Evidence
from neurionpy.protos.cosmos.evidence.v1beta1.query_pb2 import (
    QueryAllEvidenceRequest,
    QueryAllEvidenceResponse,
    QueryEvidenceRequest,
    QueryEvidenceResponse,
)


class EvidenceRestClient(Evidence):
    """Evidence REST client."""

    API_URL = "/cosmos/evidence/v1beta1"

    def __init__(self, rest_api: RestClient) -> None:
        """
        Initialize.

        :param rest_api: RestClient api
        """
        self._rest_api = rest_api

    def Evidence(self, request: QueryEvidenceRequest) -> QueryEvidenceResponse:
        """
        Evidence queries evidence based on evidence hash.

        :param request: QueryEvidenceRequest

        :return: QueryEvidenceResponse
        """
        json_response = self._rest_api.get(
            f"{self.API_URL}/evidence/{request.evidence_hash}",
        )
        return Parse(json_response, QueryEvidenceResponse())

    def AllEvidence(self, request: QueryAllEvidenceRequest) -> QueryAllEvidenceResponse:
        """
        AllEvidence queries all evidence.

        :param request: QueryAllEvidenceRequest

        :return: QueryAllEvidenceResponse
        """
        json_response = self._rest_api.get(f"{self.API_URL}/evidence", request)
        return Parse(json_response, QueryAllEvidenceResponse())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: neurion/sanctum/dataset_usage_request.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'neurion/sanctum/dataset_usage_request.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+neurion/sanctum/dataset_usage_request.proto\x12\x0fneurion.sanctum\"\x87\x03\n\x13\x44\x61tasetUsageRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\x12:\n\x06result\x18\x03 \x01(\x0e\x32*.neurion.sanctum.DatasetUsageRequestResult\x12\x12\n\ndataset_id\x18\x04 \x01(\x04\x12\x0e\n\x06intent\x18\x05 \x01(\t\x12\x1b\n\x13training_repository\x18\x06 \x01(\t\x12\x10\n\x08\x66\x65\x65_paid\x18\x07 \x01(\x04\x12\x1a\n\x12\x64\x65\x63ision_timestamp\x18\x08 \x01(\x04\x12\x16\n\x0e\x64\x65\x63ision_maker\x18\t \x01(\t\x12\x17\n\x0f\x64\x65\x63ision_reason\x18\n \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x0b \x01(\x04\x12\x15\n\rdispute_model\x18\x0c \x01(\t\x12!\n\x19\x64ispute_resolution_reason\x18\r \x01(\t\x12\x10\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x0e \x01(\t\x12\x0f\n\x07\x63ontact\x18\x0f \x01(\t*\xd0\x02\n\x19\x44\x61tasetUsageRequestResult\x12.\n*DATASET_USAGE_REQUEST_RESULT_NOT_AVAILABLE\x10\x00\x12)\n%DATASET_USAGE_REQUEST_RESULT_ACCEPTED\x10\x01\x12)\n%DATASET_USAGE_REQUEST_RESULT_REJECTED\x10\x02\x12*\n&DATASET_USAGE_REQUEST_RESULT_CANCELLED\x10\x03\x12+\n\'DATASET_USAGE_REQUEST_RESULT_PROCESSING\x10\x04\x12)\n%DATASET_USAGE_REQUEST_RESULT_FINISHED\x10\x05\x12)\n%DATASET_USAGE_REQUEST_RESULT_DISPUTED\x10\x06\x42\x19Z\x17neurion/x/sanctum/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'neurion.sanctum.dataset_usage_request_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\027neurion/x/sanctum/types'
  _globals['_DATASETUSAGEREQUESTRESULT']._serialized_start=459
  _globals['_DATASETUSAGEREQUESTRESULT']._serialized_end=795
  _globals['_DATASETUSAGEREQUEST']._serialized_start=65
  _globals['_DATASETUSAGEREQUEST']._serialized_end=456
# @@protoc_insertion_point(module_scope)



import gzip
from typing import Any, Optional

from neurionpy.synapse.coins import parse_coins
from neurionpy.common.utils import json_encode
from neurionpy.crypto.address import Address
from neurionpy.protos.cosmwasm.wasm.v1.tx_pb2 import (
    MsgClearAdmin,
    MsgExecuteContract,
    MsgInstantiateContract,
    MsgMigrateContract,
    MsgStoreCode,
    MsgUpdateAdmin,
)


def create_cosmwasm_store_code_msg(
    contract_path: str, sender_address: Address
) -> MsgStoreCode:
    """Create cosmwasm store code message.

    :param contract_path: contract path
    :param sender_address: sender address
    :return: cosmwasm store code message
    """
    with open(contract_path, "rb") as contract_file:
        wasm_byte_code = gzip.compress(contract_file.read(), 9)

    msg = MsgStoreCode(
        sender=str(sender_address),
        wasm_byte_code=wasm_byte_code,
    )

    return msg


def create_cosmwasm_instantiate_msg(
    code_id: int,
    args: Any,
    label: str,
    sender_address: Address,
    funds: Optional[str] = None,
    admin_address: Optional[Address] = None,
) -> MsgInstantiateContract:
    """Create cosmwasm instantiate message.

    :param code_id: code id
    :param args: args
    :param label: label
    :param sender_address: sender address
    :param funds: funds, defaults to None
    :param admin_address: admin address, defaults to None
    :return: cosmwasm instantiate message
    """
    msg = MsgInstantiateContract(
        sender=str(sender_address),
        code_id=code_id,
        msg=json_encode(args).encode("UTF8"),
        label=label,
    )

    if funds is not None:
        msg.funds.extend(parse_coins(funds))
    if admin_address is not None:
        msg.admin = str(admin_address)  # noqa

    return msg


def create_cosmwasm_migrate_msg(
    code_id: int,
    args: Any,
    contract_address: Address,
    sender_address: Address,
) -> MsgMigrateContract:
    """Create cosmwasm migrate message.

    :param code_id: code id
    :param args: args
    :param contract_address: sender address
    :param sender_address: sender address
    :return: cosmwasm migrate message
    """
    msg = MsgMigrateContract(
        sender=str(sender_address),
        code_id=code_id,
        msg=json_encode(args).encode("UTF8"),
        contract=str(contract_address),
    )

    return msg


def create_cosmwasm_execute_msg(
    sender_address: Address,
    contract_address: Address,
    args: Any,
    funds: Optional[str] = None,
) -> MsgExecuteContract:
    """Create cosmwasm execute message.

    :param sender_address: sender address
    :param contract_address: contract address
    :param args: args
    :param funds: funds, defaults to None
    :return: cosmwasm execute message
    """
    msg = MsgExecuteContract(
        sender=str(sender_address),
        contract=str(contract_address),
        msg=json_encode(args).encode("UTF8"),
    )
    if funds is not None:
        msg.funds.extend(parse_coins(funds))

    return msg


def create_cosmwasm_update_admin_msg(
    sender_address: Address,
    contract_address: Address,
    new_admin: Address,
) -> MsgExecuteContract:
    """Create cosmwasm update admin message.

    :param sender_address: sender address
    :param contract_address: contract address
    :param sender_address: sender address
    :param new_admin: new admin address
    :return: cosmwasm update admin message
    """
    msg = MsgUpdateAdmin(
        sender=str(sender_address),
        contract=str(contract_address),
        new_admin=str(new_admin),
    )

    return msg


def create_cosmwasm_clear_admin_msg(
    sender_address: Address,
    contract_address: Address,
) -> MsgExecuteContract:
    """Create cosmwasm clear admin message.

    :param sender_address: sender address
    :param contract_address: contract address
    :param sender_address: sender address
    :return: cosmwasm clear admin message
    """
    msg = MsgClearAdmin(
        sender=str(sender_address),
        contract=str(contract_address),
    )

    return msg
